@@ -9,7 +9,7 @@
 #
 package MooseX::TrackDirty::Attributes::Trait::Method::Accessor;
 {
-  $MooseX::TrackDirty::Attributes::Trait::Method::Accessor::VERSION = '1.000';
+  $MooseX::TrackDirty::Attributes::Trait::Method::Accessor::VERSION = '2.000';
 }
 
 # ABSTRACT: Track dirtied attributes
@@ -95,13 +95,15 @@ sub _generate_is_dirty_method_inline {
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 MooseX::TrackDirty::Attributes::Trait::Method::Accessor - Track dirtied attributes
 
 =head1 VERSION
 
-version 1.000
+This document describes 2.000 of MooseX::TrackDirty::Attributes::Trait::Method::Accessor - released February 28, 2012 as part of MooseX-TrackDirty-Attributes.
 
 =head1 DESCRIPTION
 
@@ -110,8 +112,34 @@ with it; you want L<MooseX::TrackDirty::Attributes>.
 
 =head1 SEE ALSO
 
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<MooseX::TrackDirty::Attributes|MooseX::TrackDirty::Attributes>
+
+=item *
+
 L<MooseX::TrackDirty::Attributes>
 
+=back
+
+=head1 SOURCE
+
+The development version is on github at L<http://github.com/RsrchBoy/moosex-trackdirty-attributes>
+and may be cloned from L<git://github.com/RsrchBoy/moosex-trackdirty-attributes.git>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/RsrchBoy/moosex-trackdirty-attributes/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Chris Weyl <cweyl@alumni.drew.edu>
